@@ -24,8 +24,8 @@ def _validate(response):
     data = request.body
 
     if DEBUG:
-        print "{} {} ({}) => {}: {}".format(request.method, url, data,
-                                            status_code, response.text)
+        print("{} {} ({}) => {}: {}".format(request.method, url, data,
+                                            status_code, response.text))
 
     try:
         data = json.loads(data) if data else None
@@ -179,7 +179,8 @@ class APIClient(json.JSONEncoder):
             response = self.session.post(url, files=data)
         else:
             data = json.dumps(data)
-            headers = {'content_type': 'json'}.update(self.session.headers)
+            headers = {'Content-Type': 'application/json'}
+            headers.update(self.session.headers)
             response = self.session.post(url, data=data, headers=headers)
 
         result = _validate(response).json()
@@ -194,7 +195,8 @@ class APIClient(json.JSONEncoder):
             response = self.session.post(url, files=data)
         else:
             data = json.dumps(data)
-            headers = {'content_type': 'json'}.update(self.session.headers)
+            headers = {'Content-Type': 'application/json'}
+            headers.update(self.session.headers)
             response = self.session.post(url, data=data, headers=headers)
 
         results = _validate(response).json()
